@@ -23,7 +23,6 @@
  * configure dialog for kpowersave
  * \brief 	In this file can be found all configure dialog related code. 
  * \author 	Danny Kukawka, <dkukawka@suse.de>, <danny.kukawka@web.de>
- * \version 	0.6.0
  * \date    	2005
  * \todo	fix dpms spinbox handling. be sure that e.g. value for poweroff
  *		could not be lower than the calue for suspend.
@@ -802,6 +801,52 @@ void ConfigureDialog::cB_disablePM_toggled(bool state){
 	sB_powerOff->setEnabled(!state);
 }
 
+/*!
+ * SLOT: called if the standby QSpinBoxes for DPMS timout is changed.
+ */
+void ConfigureDialog::sB_standby_valueChanged() {
+	
+	if (initalised) {
+		if (sB_standby->value() == 0 ) 
+			return;
+		if ( sB_standby->value() > sB_suspend->value()) {
+			sB_suspend->setValue(sB_standby->value());
+		}
+	}
+}
+
+/*!
+ * SLOT: called if the suspend QSpinBoxes for DPMS timout is changed.
+ */
+void ConfigureDialog::sB_suspend_valueChanged() {
+
+	if (initalised) {
+		if (sB_suspend->value() == 0 ) 
+			return;
+
+		if ( sB_suspend->value() < sB_standby->value()) {
+			sB_standby->setValue(sB_suspend->value());
+		}
+		if ( sB_suspend->value() > sB_powerOff->value()) {
+			sB_powerOff->setValue(sB_suspend->value());
+		}
+	}
+}
+
+/*!
+ * SLOT: called if the powerOff QSpinBoxes for DPMS timout is changed.
+ */
+void ConfigureDialog::sB_powerOff_valueChanged() {
+
+	if (initalised) {
+		if (sB_powerOff->value() == 0 ) 
+			return;
+		if ( sB_powerOff->value() < sB_suspend->value()) {
+			sB_suspend->setValue(sB_powerOff->value());
+		}
+	}
+}
+
 /* ----  END DPMS SECTION ---- */
 
 /* ---- START Inactivity SECTION ---- */
