@@ -1,7 +1,7 @@
  /**************************************************************************
  *   Copyright (C) 2004 by  Thomas Renninger                               *
  *                            <trenn@suse.de> and                          *
- *                          Danny Kukawka                                  *
+ *            2004-2006 by  Danny Kukawka                                  *
  *                            <dkukawka@suse.de>, <danny.kukawka@web.de>   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -84,10 +84,14 @@ kpowersave::kpowersave( bool force_acpi_check ) : KSystemTray(0, "kpowersave"),
 	
 	// connect to signals for messages/popups
 	connect(pdaemon, SIGNAL(forwardClientMessage(QString)), this, SLOT(showClientMessage(QString)));	
-	connect(pdaemon, SIGNAL(powersaveNotRunningDialog()), this, SLOT(showPowersaveErrorMsg()));
 	connect(pdaemon, SIGNAL(progressDialogRequest(QString)), this, SLOT(showProgressDialog(QString)));
 	//connect(pdaemon, SIGNAL(progressDialogRequest(QString, int)), this, SLOT(showProgressDialog(QString, int)));
+	
+	// connect to error mesages
 	connect(autoSuspend, SIGNAL(displayErrorMsg(QString)), this, SLOT(showClientMessage(QString)));	
+	connect(pdaemon, SIGNAL(powersaveNotRunningDialog()), this, SLOT(showPowersaveErrorMsg()));
+	connect(pdaemon, SIGNAL(dbusErrorMsgDialog(int)), this, SLOT(showDBusErrorMsg(int)));
+	connect(pdaemon, SIGNAL(halErrorMsgDialog()), this, SLOT(showHalErrorMsg()));
 
 	// connect to events
 	connect(pdaemon, SIGNAL(lidclosed()), this, SLOT(lockscreen_on_lidcloseEvent()));
@@ -142,7 +146,6 @@ kpowersave::kpowersave( bool force_acpi_check ) : KSystemTray(0, "kpowersave"),
 			   "SUSPEND2RAM_FORCE=\"yes\" in /etc/powersave/sleep.");
 	dummy_trans = i18n("Additionally, please mail the output of %1 to %2 . Thanks!").arg("").arg("");
 	dummy_trans = i18n("Power consumption");
-	
 }
 	
 
@@ -318,16 +321,10 @@ void kpowersave::loadIcon(){
 			pixmap_name_tmp = QString("laptoppower");
 		else
 			pixmap_name_tmp = QString("laptopcharge");
-	
-		hal_error_shown = false;
-		DISPLAY_HAL_ERROR_Timer->stop();
 	}
 	else if (pdaemon->on_AC_power == HAL_ERROR || pdaemon->on_AC_power == UNKNOWN ) {
-		if(!hal_error_shown && pdaemon->on_AC_power == HAL_ERROR) {
-			if(!DISPLAY_HAL_ERROR_Timer->isActive() && !hal_error_shown) {
-				hal_error_shown = true;
-				DISPLAY_HAL_ERROR_Timer->start(HAL_ERROR_MSG_intervall, true);
-			}
+		if(pdaemon->on_AC_power == HAL_ERROR) {
+			// TODO: add some default ?
 		}
 		pixmap_name_tmp = QString("ERROR");
 	}
@@ -357,7 +354,6 @@ void kpowersave::loadIcon(){
 			icon_state_changed = false;
 			BAT_WARN_ICON_Timer->start(BAT_icon_BG_intervall, true);
 		}
-		hal_error_shown = false;
 	}
 
 	// reload icon only if new icon selected
@@ -450,7 +446,10 @@ void kpowersave::updateTooltip(){
 	num3.setNum(pdaemon->left % 60);
 	num3 = num3.rightJustify(2, '0');
 
-	if (pdaemon->on_AC_power == AC_ONLINE) {
+	if (pdaemon->on_AC_power == HAL_ERROR || pdaemon->battery_state == BAT_HAL_ERROR || pdaemon->hal_terminated){
+		tmp = i18n("No information about battery and AC status available");
+	} 
+	else if (pdaemon->on_AC_power == AC_ONLINE) {
 		if (pdaemon->perc == 100) tmp = i18n("Plugged in -- fully charged");
 		// assume that no battery is there
 		else {
@@ -477,11 +476,7 @@ void kpowersave::updateTooltip(){
 				}
 			}
 		}
-	}
-	else if (pdaemon->on_AC_power == HAL_ERROR || pdaemon->battery_state == BAT_HAL_ERROR){
-		tmp = i18n("No information about battery and AC status available");
-	}
-	else{
+	} else{
 		if (pdaemon->left >= 0){
 			tmp = i18n("Running on batteries -- %1% charged (%2:%3 hours remaining)")
 			      .arg(pdaemon->perc).arg(pdaemon->left / 60).arg(num3);
@@ -545,9 +540,21 @@ void kpowersave::slotAbout()
 void kpowersave::slotReportBug()
 {
 #ifdef DISTRO_IS_SUSE
+ #ifdef DISTRO_IS_SLES_SLED
+	kapp->invokeBrowser("https://bugzilla.novell.com/");
+ #else
 	kapp->invokeBrowser("http://opensuse.org/Report_a_Bug");
-#else
+ #endif
+#else 
+ #ifdef DISTRO_IS_ALTLINUX
+	kapp->invokeBrowser("http://bugzilla.altlinux.org/");
+ #else
+  #ifdef DISTRO_IS_UBUNTU
+	kapp->invokeBrowser("https://launchpad.net/distros/ubuntu/+bugs");
+  #else
 	kapp->invokeBrowser("http://sourceforge.net/tracker/?group_id=124576&atid=700009");
+  #endif
+ #endif
 #endif
 }
 
@@ -744,7 +751,7 @@ bool kpowersave::do_standby(){
 
 /*!
  * \b SLOT to send the related suspend command for autosuspend if the signal
- * \ref autosuspend::autosuspendTimeExpired() was recieved. 
+ * \ref autosuspend::inactivityTimeExpired was recieved. 
  * \return boolean with the result of the operation
  * \retval true if successful 
  * \retval false if command not supported or if powersaved not running
@@ -755,7 +762,7 @@ bool kpowersave::do_autosuspend() {
 	myDebug ("kpowersave::do_autosuspend");
 	
 	autoSuspend->stop();
-	if(current_settings->autoSuspend) {
+	if(current_settings->autoSuspend && !contextMenu()->isItemChecked(AUTOSUSPEND_MENU_ID)) {
 		if(current_settings->autoInactiveAction == "Suspend to Disk") {
 			return do_suspend2disk();
 		} else if (current_settings->autoInactiveAction == "Suspend to RAM") {
@@ -767,7 +774,6 @@ bool kpowersave::do_autosuspend() {
 		}
 	}
 	else return false;
-	
 }
 
 /*!
@@ -973,7 +979,6 @@ void kpowersave::update(){
 	if (pdaemon->update_info_ac_changed == true){
 		redraw_pixmap = 1;
 		if(pdaemon->on_AC_power != HAL_ERROR && pdaemon->on_AC_power != UNKNOWN)
-			hal_error_shown = false;
 
 		pdaemon->update_info_ac_changed = FALSE;
 	}
@@ -1025,14 +1030,8 @@ void kpowersave::update(){
 		
 		/* set fixed battery limits if daemon is not available */
 		if (pdaemon->send_battery_state_change_message){
-			if (pdaemon->battery_state != BAT_HAL_ERROR )
-				hal_error_shown = false;
-
-			if ((pdaemon->battery_state == BAT_HAL_ERROR) && !hal_error_shown) {
-				if(!DISPLAY_HAL_ERROR_Timer->isActive() && !hal_error_shown) {
-					hal_error_shown = true;
-					DISPLAY_HAL_ERROR_Timer->start(HAL_ERROR_MSG_intervall, true);
-				}
+			if (pdaemon->battery_state == BAT_HAL_ERROR) { 
+				//TODO: add some default
 			}
 
 			pdaemon->send_battery_state_change_message = FALSE;
@@ -1199,6 +1198,22 @@ void kpowersave::enterEvent( QEvent *qee ){
 	if(qee == NULL) ; // to prevent compiler warning
 }
 
+/*!
+ * Event handler for mouse wheel events.  If the system supports changing display
+ * brightness and changing brightness is enabled in the current scheme settings,
+ * this will raise the brightness by one level for wheel up events and lower the 
+ * brightness by one level for wheel down events.
+ */
+void kpowersave::wheelEvent (QWheelEvent *qwe)
+{
+	if (!brightness_supported && current_settings->brightness)
+		return;
+
+	if (qwe->orientation () == Vertical) {
+		int diff = qwe->delta () > 0 ? 1 : -1;
+		pdaemon->setBrightness (pdaemon->getBrightness (false) + diff, false, false);
+	}
+}
 
 /*!
  * Reimplemented eventhandler for mousePressEvents which is involved if the user click 
@@ -1280,7 +1295,7 @@ void kpowersave::showClientMessage( QString msg ){
 }
 
 /*!
- * \b SLOT used to display messeges from powersave in kpowersave. This function 
+ * \b SLOT used to display messages from powersave in kpowersave. This function 
  * block all messeges which we have in kpowersave!
  */
 void kpowersave::showPowersaveErrorMsg( ){
@@ -1297,6 +1312,36 @@ void kpowersave::showPowersaveErrorMsg( ){
 	if (!dlg->dialogIsDisabled()) dlg->show();
 }
 
+/*!
+ * \b SLOT used to display error messages related to DBUS in kpowersave. This function 
+ * block all messeges which we have in kpowersave!
+ */
+void kpowersave::showDBusErrorMsg( int type ){
+	myDebug ("kpowersave::showDBusErrorMsg");
+
+	QString msg;
+	QString dlg_name; 
+
+	switch (type) {
+		case DBUS_NO_RIGHTS:
+			msg = i18n("You are not permitted to connect to the powersave daemon via DBUS. "
+				   "Please check your DBUS configuration and installation. ");
+			dlg_name = "dbusNoRights";
+			break;
+		case DBUS_NOT_RUNNING:
+			msg = i18n("The DBUS daemon is not running.\nStarting it will "
+				   "provide full functionality: /etc/init.d/dbus start");
+			dlg_name = "dbusNotRunning";
+			break;
+		default:
+			return;
+	} 
+
+	infoDialog *dlg = new infoDialog( config, i18n("Warning"), msg, 
+					 i18n("Don't show this message again."), dlg_name);
+
+	if (!dlg->dialogIsDisabled()) dlg->show();
+}
 
 /*!
  * This function/SLOT is invoked if the powersave daemon send messages
@@ -1534,10 +1579,18 @@ void kpowersave::setSchemeSettings(){
 void kpowersave::showHalErrorMsg() {
 	myDebug("kpowersave::showHalErrorMsg");
 
-	if(hal_error_shown && !DISPLAY_HAL_ERROR_Timer->isActive()) {
+	if(hal_error_shown && !DISPLAY_HAL_ERROR_Timer->isActive() && pdaemon->hal_terminated){
 		KPassivePopup::message(i18n("ERROR"),
 				       i18n("Could not get information from HAL. The haldaemon is maybe not running."),
-				       SmallIcon("messagebox_warning", 20), this, i18n("Error"), 3000);
+				       SmallIcon("messagebox_warning", 20), this, i18n("Error"), 5000);
+	}
+	else if (pdaemon->hal_terminated && !hal_error_shown && !DISPLAY_HAL_ERROR_Timer->isActive()) {
+		hal_error_shown = true;
+		DISPLAY_HAL_ERROR_Timer->start(HAL_ERROR_MSG_intervall, true);
+	}
+	else if (!pdaemon->hal_terminated) {
+		hal_error_shown = false;
+		DISPLAY_HAL_ERROR_Timer->stop();
 	}
 
 	return;
@@ -1757,6 +1810,54 @@ QString kpowersave::currentCPUFreqPolicy() {
 	else return "ERROR: powersaved not running";
 }
 
+/*!
+ * DCOP Interface funtion to send a list with the allowed  
+ * CPU Frequency states.
+ * \return QStringList with the supported CPUFreq states
+ */
+QStringList kpowersave::list_CPUFreqPolicies() {
+	myDebug("kpowersave::list_CPUFreqPolicy");
+
+	QStringList ret_list;
+	if (pdaemon->cpufreq_policy != CPU_UNSUPP) {
+		ret_list.append("PERFORMANCE");
+		ret_list.append("DYNAMIC");
+		ret_list.append("POWERSAVE");
+	}
+	else {
+		ret_list.append("NOT SUPPORTED");
+	}
+	return ret_list;
+}
+
+/*!
+ * DCOP Interface funtion to set the current CPUFreq policy
+ * \param policy QString with the policy to set, only values from
+ * 		 list_CPUFreqPolicies are allowed (except "NOT SUPPORTED")
+ * \return boolean with the result of set the requested CPUFreq policy
+ * \retval true if successful set 
+ * \retval false if not supported or any other failure
+ */
+bool kpowersave::do_setCPUFreqPolicy( QString policy ) {
+	myDebug("kpowersave::set_CPUFreqPolicy");
+
+	if (pdaemon->cpufreq_policy != CPU_UNSUPP) {
+		if (policy == "PERFORMANCE") {
+			pdaemon->setCPUFreqPolicy( CPU_HIGH );
+		} else if (policy == "DYNAMIC") {
+			pdaemon->setCPUFreqPolicy( CPU_AUTO );
+		} else if (policy == "POWERSAVE") {
+			pdaemon->setCPUFreqPolicy( CPU_LOW );
+		} else {
+			return false;
+		}
+		return true;
+	} else {
+		return false;
+	}
+}
+
+
 /*!
  * DCOP Interface funtion to send a list with the supported and enabled 
  * sleeping states.
@@ -1805,6 +1906,29 @@ QStringList kpowersave::list_schemes(){
 	return _schemeList;
 }
 
+
+/*!
+ * DCOP Interface funtion to set the current scheme.
+ * \return boolean with the result of set the requested scheme
+ * \retval false if failed (e.g. scheme is not in the list)
+ * \retval true if scheme found and set
+ * \param _scheme QString with the scheme to set, scheme should be 
+ *		  named as list from list_schemes()
+ */
+bool kpowersave::do_setScheme( QString _scheme ) {
+	myDebug("kpowersave::do_setScheme");
+
+	int index = pdaemon->schemes.schemeList().findIndex(_scheme);
+
+	if (index != -1) {
+		do_setActiveScheme(index);
+		return true;
+	}
+	else {
+		return false;
+	}
+}
+
 /*!
  * DCOP Interface funtion to send the suspend to disk command to powersave.
  * \return boolean with the result of calling do_suspend2disk()
@@ -1843,16 +1967,47 @@ bool kpowersave::do_standBy(){
 
 /*!
  * DCOP Interface funtion to stop/start the Autosuspend 
- * \param activate boolean which tell if the autosuspend should be stopped (true)
- *		   or started (flase).
+ * \param disable boolean which tell if the autosuspend should be stopped (true)
+ *		   or started (false).
  */
-void  kpowersave::disableAutosuspend( bool activate ){
+void kpowersave::disableAutosuspend( bool disable ){
 	myDebug("kpowersave::disableAutosuspend");	
 
-	if(activate) autoSuspend->stop();
-	else setAutoSuspend(true);
+	if(current_settings->autoSuspend && current_settings->autoInactiveActionAfter > 0) {
+		if (disable) {
+			if ( !contextMenu()->isItemChecked(AUTOSUSPEND_MENU_ID)) {
+				autoSuspend->stop();
+				contextMenu()->setItemChecked(AUTOSUSPEND_MENU_ID, true);
+			}
+		}
+		else {
+			contextMenu()->setItemChecked(AUTOSUSPEND_MENU_ID, false);
+			setAutoSuspend(true);
+		}
+	}
 }
 
+/*!
+ * DCOP Interface funtion to open/close the detailed dialog.
+ */
+void kpowersave::showDetailedDialog( ){
+	myDebug("kpowersave::showDetailedDialog");
+
+	if (detailedIsShown) {
+		detailedDlg->close();
+		delete(detailedDlg);
+		closedetaileddialog();
+		return;
+	}
+
+	detailedDlg = new detaileddialog(pdaemon, &fullIcon);
+
+	if (detailedDlg) {
+		detailedDlg->show();
+		detailedIsShown = true;
+	}
+
+}
 
 /*!
  * DCOP Interface funtion to open the configure dialog.
