@@ -80,6 +80,11 @@ pDaemon::pDaemon(){
 	update_info_cpufreq_speed_changed = true;
 	update_info_scheme_info_changed = true;
 
+	// to store the state of our central services
+	powersaved_terminated = false;
+	dbus_terminated =  false;
+	hal_terminated = false;
+
 	cpufreq_policy = CPU_UNSUPP;
 	battery_state = -1;
 
@@ -380,10 +385,7 @@ int pDaemon::setActiveScheme( QString schemename ){
  * Check whether we can access the daemon via client or data socket 
  * \return A integer value with the result of the check
  * \retval 1 if daemon is available
- * \retval POWERSAVED_ERROR_SOCKET_ERROR
- * \retval POWERSAVED_NO_RIGHTS
- * \retval POWERSAVED_ERROR
- * \retval (-n) for some other errors if daemon is not running
+ * \retval -1 if daemon is not available
  */
 int pDaemon::checkDaemon(){
 	myDebug("pDaemon::checkDaemon");
@@ -466,7 +468,7 @@ int pDaemon::readDaemonData(){
 			updateSchemeInfo();
 		}
 		dbus_message_unref( reply );
-	} 
+	}
 
 	// enable suspend/standy by if we are ran as root
 	if (getuid() == 0)
@@ -568,40 +570,19 @@ int pDaemon::readDaemonData(){
 	if (ret < 0) {
 		handleGetBatteryInfoError(ret);
 	} else {
-		new_value = bg.remaining_percent;
-		if (new_value != UNKNOWN) {
-			if (new_value != perc){
-				update_info_battery_perc_changed = true;
-				perc = new_value;
-			}
+		if (bg.remaining_percent != perc){
+			update_info_battery_perc_changed = true;
+			perc = bg.remaining_percent;
 		}
 	
-		new_value = bg.remaining_minutes;
-		if (new_value != UNKNOWN) {
-			if (new_value != left){
-				update_info_battery_perc_changed = true;
-				left = new_value;
-			}
+		if (bg.remaining_minutes != left){
+			update_info_battery_perc_changed = true;
+			left = bg.remaining_minutes;
 		}
-		
-		new_value = bg.charging_state;
-		if ( new_value != CHARG_STATE_UNKNOWN ) {
-			switch (new_value) {
-			case CHARG_STATE_CHARGING:
-				new_value = CHARG_STATE_CHARGING;
-				break;
-			case CHARG_STATE_DISCHARGING:
-				new_value = CHARG_STATE_DISCHARGING;
-				break;
-			default:
-				new_value = CHARG_STATE_UNKNOWN;
-				break;
-			}
-			
-			if (new_value != charge_state){
-				update_info_battery_charge_changed = true;
-				charge_state = new_value;
-			}
+
+		if (bg.charging_state != charge_state){
+			update_info_battery_charge_changed = true;
+			charge_state = bg.charging_state;
 		}
 	}
 
@@ -1074,7 +1055,8 @@ void pDaemon::getCPUMaxSpeed() {
 /*!
  * \b SLOT to recheck the powersave daemon if there is any problem to connect
  * to the powersave library. This SLOT called by \ref checkSystemTimeout() through a 
- * QTimer::singleShot with a 4 second intervall and within mousePressEvent() .
+ * QTimer::singleShot with a 4 second intervall and within mousePressEvent().
+ * \param onetime boolean to allow recheck without start the check_system_timer timer
  */
 void pDaemon::recheckDaemon(){
 	myDebug ("pDaemon::recheckDaemon");
@@ -1089,7 +1071,15 @@ void pDaemon::recheckDaemon(){
 			checkSystemTimeout();
 		}
 		// daemon is not running for at least xx seconds 
-		emit powersaveNotRunningDialog();
+		if (powersaved_terminated) {
+			emit powersaveNotRunningDialog();
+		} else if (dbus_conn->noRights()) {
+			dbus_terminated = false;	
+			emit dbusErrorMsgDialog (DBUS_NO_RIGHTS);
+		} else {
+			emit dbusErrorMsgDialog (DBUS_NOT_RUNNING);
+		}
+
 		emit generalDataChanged();
 	}
 	else {
@@ -1117,8 +1107,19 @@ void pDaemon::processClientMessage( msg_type type, QString signal, int value ){
 			myDebug("D-BUS Event: '%s'", signal.ascii());
 			if ( signal.startsWith("dbus.terminate")){
 				QTimer::singleShot(4000, this, SLOT(recheckDaemon()));
+				dbus_terminated = true;
 				switchToNonDaemonMode();
 			}
+			else if ( signal.startsWith("hal.")) {
+				if ( signal.startsWith("hal.terminate"))
+					hal_terminated = true;
+				if ( signal.startsWith("hal.started"))
+					hal_terminated = false;
+				
+				emit halErrorMsgDialog();
+				readDaemonData();
+				emit generalDataChanged();
+			}
 			break;
 		case ACPI_EVENT:
 			// we don't use acpi events here
@@ -1131,7 +1132,7 @@ void pDaemon::processClientMessage( msg_type type, QString signal, int value ){
 			myDebug("Powersave Event: '%s'", signal.ascii());
 			if ( signal.startsWith("daemon.terminate")){
 				// DON NO RECHECK !!! We do this if we get signal: dbus.terminate
-				// QTimer::singleShot(4000, this, SLOT(recheckDaemon()));
+				powersaved_terminated = true;
 				switchToNonDaemonMode();
 			}
 			else if ( signal.startsWith("daemon.start")){
@@ -1351,7 +1352,9 @@ void pDaemon::switchToDaemonMode(){
 		
 		update_info_cpufreq_policy_changed = true;
 		update_info_sleep_state_changed = true;
-	
+		powersaved_terminated = false;
+		dbus_terminated = false;
+
 		emit generalDataChanged();
 	}
 	else switchToNonDaemonMode();
